.onLoad <- function(libname, pkgname){
  options(rtrek_antidos = 1)
}

rtrek_api_time <- new.env()
